@@ -1,3 +1,6 @@
+"""
+Provides the ability to perform maintenance on a database.
+"""
 import logging
 import os
 import shutil
@@ -5,14 +8,16 @@ import shutil
 import six.moves.urllib.parse as urlparse
 
 LOG = logging.getLogger(__name__)
+# total of 8 weeks/2 months of backups
+MAX_BACKUP_COUNT = 8
 
 
 def backup(conf):
     """
     create a backup copy of the database file.
+
+    :param oslo.config.cfg.ConfigOpts conf: an instance of configuration
     """
-    # total of 8 weeks/2 months of backups
-    MAX_BACKUP_COUNT = 8
 
     LOG.debug('starting database backup process')
     default_db_name = urlparse.urlparse(
@@ -31,5 +36,5 @@ def backup(conf):
         shutil.copy2(default_db_name, dfn)
         LOG.info('backup complete')
     else:
-        LOG.warn('Database [%s] does not exist, no backup taken.',
-                 default_db_name)
+        LOG.warning('Database [%s] does not exist, no backup taken.',
+                    default_db_name)
