@@ -100,3 +100,24 @@ def initialize(args):
     # path of the most specific config file found.
     if not cfg.CONF.config_dir:
         cfg.CONF.config_dir = os.path.dirname(cfg.CONF.config_file[-1])
+
+
+def list_opts():
+    """
+    Returns a list of oslo.config options available in the library.
+
+    The returned list includes all oslo.config options which may be registered
+    at runtime by the library.
+
+    Each element of the list is a tuple. The first element is the name of the
+    group under which the list of elements in the second element will be
+    registered. A group name of None corresponds to the [DEFAULT] group in
+    config files.
+
+    The purpose of this is to allow tools like the Oslo sample config file
+    generator to discover the options exposed to users by this library.
+
+    :returns: a list of (group_name, opts) tuples
+    """
+    from seedbox.common import tools
+    return tools.make_opt_list([OPTS], None)
